[![PyPI Version](https://badge.fury.io/py/ucdp.svg)](https://badge.fury.io/py/ucdp)
[![Python Build](https://github.com/nbiotcloud/ucdp/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/ucdp/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/ucdp/badge/?version=stable)](https://ucdp.readthedocs.io/en/stable/)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/ucdp/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/ucdp?branch=main)
[![versions](https://img.shields.io/pypi/pyversions/ucdp.svg)](https://github.com/nbiotcloud/ucdp)

# Unified Chip Design Platform

* [Documentation](https://ucdp.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/ucdp/)
* [Sources](https://github.com/nbiotcloud/ucdp)
* [Issues](https://github.com/nbiotcloud/ucdp/issues)

## Installation

Installing it is pretty easy:

```bash
pip install ucdp
```
